<?php
$lang['0_product'] = 'Produkt';
$lang['1_service'] = 'Dienstleistung';
$lang['2_discount'] = 'Erm&auml;&szlig;igung';
$lang['3_shipping'] = 'Versandkosten';
$lang['4_tax'] = 'Steuer';
$lang['addedit_billingform_template'] = 'Rechnungsformularvorlage hinzuf&uuml;gen/bearbeiten';
$lang['addedit_completion_template'] = 'Vollendungsvorlage hinzuf&uuml;gen/bearbeiten';
$lang['addedit_confirmorder_template'] = 'Bestellungsbest&auml;tigungsvorlage hinzuf&uuml;gen/bearbeiten';
$lang['addedit_gateway_complete_template'] = 'Bezahlungsschnittstellenvorlage hinzuf&uuml;gen/bearbeiten';
$lang['addedit_invoice_template'] = 'Rechnungsvorlage hinzuf&uuml;gen/bearbeiten';
$lang['addedit_paymentform_template'] = 'Zahlungsformularvorlage hinzuf&uuml;gen/bearbeiten';
$lang['address1'] = 'Adresszeile 1';
$lang['address2'] = 'Adresszeile 2';
$lang['address_handling'] = 'Adressenhandhabung';
$lang['add_msg_template'] = 'Neue Nachrichtenvorlage hinzuf&uuml;gen';
$lang['admin_email_addresses'] = 'eine durch Kommata getrennte Liste von Administrator-E-Mail-Adressen, die verwendet werden, wenn eine neue Bestellung get&auml;tigt wird';
$lang['admin_email_template'] = 'Administrator-E-Mail-Vorlage';
$lang['amount'] = 'Betrag';
$lang['amt_due'] = 'f&auml;lliger Betrag';
$lang['any'] = 'egal';
$lang['ask_delete'] = 'Sind sie sicher, dass sie dies l&ouml;schen wollen?';
$lang['ask_delete_order'] = 'Sind sie sicher, dass sie diese Bestellung l&ouml;schen wollen? Es wird normalerweise nicht empfohlen, Bestellungen zu l&ouml;schen';
$lang['ask_delete_payment'] = 'Sind sie sich sicher, dass sie alle Eintr&auml;ge dieser Bezahlung entfernen wollen?';
$lang['ask_edit_billing'] = 'Sind sie sicher, dass sie die Bestellungsinformationen f&uuml;r diese Bestellung wie oben angegeben bearbeiten wollen?';
$lang['ask_manual_payment'] = 'Sind Sie sicher, dass Sie f&uuml;r diesen Betrag manuell mit Ihrer Kreditkarte zahlen m&ouml;chten?';
$lang['ask_saveprefs'] = 'Sind Sie sicher, dass Sie die Einstellungen dieses Moduls &auml;ndern m&ouml;chten?\nFehlerhafte Einstellungen k&ouml;nnten die Funktionalit&auml;t Ihrer Webseite beinflussen.';
$lang['ask_setorderstatus'] = 'Es wurde eine m&ouml;gliche &Auml;nderung des Bestellungsstatus festgestellt. Wollen sie den Status setzen auf:';
$lang['back'] = 'zur&uuml;ck';
$lang['back_to_orders'] = 'zur&uuml;ck zu den Bestellungen';
$lang['backorder'] = 'im R&uuml;ckstand';
$lang['balancedue'] = 'f&auml;lliger Restbetrag (teilweise bezahlt)';
$lang['bill_to'] = 'Rechnung stellen an';
$lang['billing'] = 'Rechnungen';
$lang['billing_address'] = 'Rechnungsadresse';
$lang['billing_form_templates'] = 'Rechnungsformularvorlage';
$lang['billing_info'] = 'Rechnungsinformation';
$lang['body'] = 'Nachrichtenk&ouml;rper';
$lang['cancel'] = 'Abbrechen';
$lang['cancelled'] = 'Abgebrochen';
$lang['captcha_title'] = 'Captcha-Text';
$lang['cart_module'] = 'Warenkorb-Modul';
$lang['cart_settings'] = 'Warenkorb-Einstellungen';
$lang['cash'] = 'Bar';
$lang['cc_AMEX'] = 'American Express';
$lang['cc_Discover'] = 'Herausfinden';
$lang['cc_MasterCard'] = 'Mastercard';
$lang['cc_Visa'] = 'Visa';
$lang['city'] = 'Ort';
$lang['company'] = 'Firma';
$lang['completed'] = 'vollendet';
$lang['completion_templates'] = 'Vollendungsvorlage';
$lang['confirmed'] = 'best&auml;tigt';
$lang['confirm_order'] = 'Bitte best&auml;tigen sie ihre Bestellung';
$lang['confirmation_form_templates'] = 'Best&auml;tigungsformularvorlage';
$lang['confirmation_num'] = 'Best&auml;tigungsnummer';
$lang['cookie'] = 'Im Cookie gespeicherte Adresse verwenden';
$lang['country'] = 'Land';
$lang['coupon_code'] = 'Couponschl&uuml;ssel';
$lang['created'] = 'angelegt';
$lang['created_by'] = 'Angelegt von';
$lang['create_invoice'] = 'Rechnung f&uuml;r diese Bestellung erstellen';
$lang['create_invoice_for'] = 'Rechnung f&uuml;r Bestellung %s erstellen';
$lang['creditcard'] = 'Kreditkarte';
$lang['creditcard_expiry'] = 'Kreditkarten-Verfallsdatum';
$lang['creditcard_number'] = 'Kreditkartennummer';
$lang['creditcard_type'] = 'Kreditkartentyp';
$lang['creditcard_verifycode'] = 'Verifizierungsschl&uuml;ssel';
$lang['customer_name'] = 'Kundenname';
$lang['date'] = 'Datum';
$lang['date_range'] = 'Datumsbereich';
$lang['dateopt_exactdates'] = 'Eingegebener Zeitraum';
$lang['dateopt_7days'] = 'Letzte 7 Tage';
$lang['dateopt_14days'] = 'Letzte 14 Tage';
$lang['dateopt_30days'] = 'Letzte 30 Tage';
$lang['dateopt_3months'] = 'Letzte 3 Monate';
$lang['dateopt_6months'] = 'Letzte 6 Monate';
$lang['dateopt_1year'] = 'Letztes Jahr';
$lang['default_templates'] = 'Standardvorlagen';
$lang['delete'] = 'L&ouml;schen';
$lang['delivered'] = 'Zugestellt';
$lang['description'] = 'Beschreibung';
$lang['desc_order_by'] = 'Sortiere nach {$billing->get_firstname()} {$billing->get_lastname()}';
$lang['destinations'] = 'Ziele';
$lang['details'] = 'Details';
$lang['dflt_billingform_template'] = 'Standard-Rechnungsformularvorlage';
$lang['dflt_confirmorder_template'] = 'Standardvorlage f&uuml;r das Bestellungsbest&auml;tigungsformular';
$lang['dflt_completion_template'] = 'Standard-Vollendungsvorlage';
$lang['dflt_gateway_complete_template'] = 'Standardvorlage f&uuml;r die Vollendung der Zahlung &uuml;ber die Zahlungsschnittstelle';
$lang['dflt_invoice_message'] = 'Vielen Dank f&uuml;r den Einkauf bei {sitename}.';
$lang['dflt_invoice_template'] = 'Standardrechnungsvorlage';
$lang['dflt_paymentform_template'] = 'Standardzahlungsformularvorlage';
$lang['discount'] = 'Erm&auml;&szlig;igung';
$lang['edit'] = 'Bearbeiten';
$lang['edit_billing_info'] = 'Rechnungsinformationen bearbeiten';
$lang['edit_report_template'] = 'Bearbeite Template f&amp;uuml;r Report: %s';
$lang['end_date'] = 'Enddatum';
$lang['email'] = 'E-Mail';
$lang['email_address'] = 'E-Mail-Adresse';
$lang['email_invoice'] = 'diese Rechnung per E-Mail an den Kunden und autorisierte Administratoren senden';
$lang['email_sent_to'] = 'E-Mail gesendet an';
$lang['email_subject'] = 'E-Mail-Betreff';
$lang['error_badcaptcha'] = 'Der eingegebene Wert stimmt nicht mit dem Captcha-Bild &uuml;berein';
$lang['error_creditcard_expired'] = 'Diese Kreditkarte ist abgelaufen';
$lang['error_encryption_problem'] = 'Beim Ver-/Entschl&uuml;sseln der Daten trat ein Problem auf.';
$lang['error_gateway_invalid_data'] = 'Die G&uuml;ltigkeit der Daten vom Zahlungsschnittstellenmodul konnte nicht best&auml;tigt werden.';
$lang['error_insufficientparams'] = 'Es fehlt ein ben&ouml;tigter Parameter';
$lang['error_invalid_address'] = 'Die angegebende Adresse ist ung&uuml;ltig. Bitte versichern sie sich, dass alle Pflichtfelder korrekt ausgef&uuml;llt sind.';
$lang['error_invalidfield'] = 'Das folgende Feld ist ung&uuml;ltig: %s';
$lang['error_invalidgateway'] = 'Das ausgew&auml;hlte Gateway ist f&uuml;r diesen Zweck ung&uuml;ltig.';
$lang['error_missingshippinginfo'] = 'unzureichende Versandinformationen angegeben';
$lang['error_namexists'] = 'etwas mit diesem Namen existiert bereits';
$lang['error_nocartmodule'] = 'Das Warenkorb-Modul konnte nicht gefunden werden. Stellen sie sicher, dass ein Warenkorb-Modul installiert und in den Einstellungen des Produktverwaltungsmoduls ausgew&auml;hlt wurde.';
$lang['error_noemailaddress'] = 'Mit dieser Benutzer-ID wurde keine E-Mail-Adresse verkn&uuml;pft.';
$lang['error_nofeumodule'] = 'Ich konnte das FrontEndUsers-Modul nicht finden.';
$lang['error_nopaymentgateway'] = 'Es wurde kein Zahlungsschnittstellenmodul angegeben.';
$lang['error_noproductsmodule'] = 'Die Produktverwaltungsmodul konnte nicht gefunden werden.';
$lang['error_norequiredgroup'] = 'Bitte geben sie eine obligatorische Mitgliedergruppe in den Einstellungen an.';
$lang['error_notloggedin'] = 'Der Benutzer ist nicht angemeldet.';
$lang['error_orderinvalid'] = 'Es gibt ein Problem mit der Bestellung (die Informationen sind widerspr&uuml;chlich).';
$lang['error_ordernotfound'] = 'Die angeforderte Bestellung wurde nicht gefunden.';
$lang['error_orderprocessing'] = 'W&auml;hrend des Bestellprozesses ist ein Fehler aufgetreten.';
$lang['error_paymentnotfound'] = 'Die angegebene Bezahlung wurde nicht gefunden.';
$lang['error_possible_hack'] = 'Potentieller Hack entdeckt: Ihre Benutzerkennung (%s) stimmt nicht mit der Kennung (%s) der Bestellung %s &amp;uuml;berein.  Bitte wenden Sie sich an den System Administrator.';
$lang['error_requiressl'] = 'Das ausgew&auml;hlte Gateway f&uuml;r diese Seite ben&ouml;tigt eine verschl&uuml;sselte Verbindung, welche noch nicht vorhanden ist.';
$lang['error_retrieve_data'] = 'Beim Versuch, die entsprechenden Informationen von der Datanbank abzufragen, ist ein Fehler aufgetreten.';
$lang['error_save'] = 'Ein Fehler ist bei der Speicherung der folgenden Dateneinheit aufgetreten: %s';
$lang['error_security_key'] = 'Der Kodierungsschl&uuml;ssel f&uuml;r diese Transaktion wurde nicht &uuml;bermittelt.';
$lang['error_paymentgateway_incompatible'] = 'Das ausgew&auml;hlte Gateway-Modul ist nicht kompatibel mit dieser Bestellverwaltung. Bitte kontaktieren Sie Ihren Administrator.';
$lang['error_permissiondenied'] = 'Erlaubnis verweigert';
$lang['error_unknownstatus'] = 'Ich habe keinen bekannten Status von der Zahlungsschnittstelle erhalten.';
$lang['error_usernotingroup'] = 'Der zur Zeit angemeldete Benutzer ist kein Mitglied der erforderlichen Gruppe.';
$lang['fax'] = 'Fax';
$lang['filter'] = 'Anzeigen';
$lang['first_name'] = 'Vorname';
$lang['firstpage'] = '<<';
$lang['friendlyname'] = 'Bestellungsverwaltung';
$lang['from'] = 'von';
$lang['gateway'] = 'Gateway';
$lang['gateway_module'] = 'Zahlungsschnittstellenmodul';
$lang['gateway_complete_templates'] = 'Zahlungsschnittstellen-Vollendungsvorlage';
$lang['gateway_failure_message'] = 'Ihre Transaktion wurde leider nicht vollendet. Entweder wurde der Vorgang abgebrochen oder ein anderer Fehler ist aufgetreten. Bitte best&auml;tigen sie ihre Zahlungsinformationen und versuchen sie es erneut. Zu ihrer Sicherheit wurde ihr Warenkorb geleert. Entschuldigung f&uuml;r eventuelle Unannehmlichkeiten.';
$lang['general_settings'] = 'Haupteinstellungen';
$lang['get_address_from_feu'] = 'Benutzerprofil verwenden';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>This module is a module for turning a filled cart into a completed Order.  This module handles collecting billing information and shipping information from the user and then either using an external payment gateway to handle payment information, or performing direct email based invoicing.</p>
  <p>This module can also optionally collect credit card information and store it in the database for later offline processing.</p>
  <p>The orders module keeps track of all orders, and allows specifying items like tracking numbers and confirmation numbers, and also allows sending emails to the client pertaining to a particular order.</p>
<h3>How Do I use It?</h3>
<p>This module works in conjunction with the Cart module.  Create a page, call it &quot;Checkout&quot; and set it&#039;s content should be &quot;{Orders}&quot;.  This page will start the Checkout process.</p>
<h3><span style=&quot;color: red;&quot;>Warning - Credit Card Information</span></h3>
<p>It is not recommended that you use the credit card number gathering mechanism unless using a secure communications mechanism and only on secured, dedicated hosts.  There is no guarantee that the database numbers (though a simple encryption mechanism is used) are not vulnerable to theft.</p>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<br/>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['help_param_invoice_prefix'] = 'Dieser Parameter erlaubt es, bis zu vier Zeichen anzugeben, die vor der Rechnungsnummer angezeigt werden.';
$lang['help_param_nocaptcha'] = 'Ist dieser Parameter gesetzt, wird die Captcha-Funktionalit&auml;t deaktiviert';
$lang['help_param_template'] = 'Eine andere als die Standardvorlage f&uuml;r die Standardaktion angeben';
$lang['hold'] = 'angehalten';
$lang['html'] = 'HTML';
$lang['html_email'] = 'E-Mail im HTML-Format versenden';
$lang['id'] = 'ID';
$lang['incomplete'] = 'unvollendet (teilweise versandt)';
$lang['info_admin_invoice_template'] = 'eine Vorlage w&auml;hlen, die f&uuml;r das Fenster mit druckfreundlicher Rechnungsanzeige verwendet wird, wenn eine Bestellung verwaltet wird';
$lang['info_adminemail_template'] = 'In diesem Template kann das Layout und der Inhalt der EMail festgelegt werden, die bei einer neuen Bestellung an den Administrator gesendet wird.';
$lang['info_allow_anon_checkout'] = 'Wird diese Option deaktiviert muss der Benutzer einen g&uuml;ltigen FrontEndUsers Login besitzen um eine Bestellung abzuschlie&szlig;en';
$lang['info_allow_creditcard_entry'] = 'Einige Payment Gateways erfordern eine Eingabe von Kreditkarten-Daten, bevor diese Daten an die Zahlungsschnittstelle &uuml;bertragen werden. Kreditkarten-Daten werden tempor&auml;r in einem verschl&uuml;sselten Format gespeichert, bis der Bestellprozess abgeschlossen oder abgebrochen wurde. Eine wiederkehrende Bereinigung der tempor&auml;ren Daten stellt sicher, dass diese Daten nicht dauerhaft auf dem Server gespeichert werden, au&szlig;er Sie aktivieren die Option, dass Kreditkartendaten gespeichert werden <em>(nicht empfohlen)</em>.';
$lang['info_billingpage'] = '<strong>Achtung:</strong> Diese Einstellungen sowie andere wie diese, erlauben dem Administrator verschiedene CMSms Seiten f&uuml;r die verschiedenen Formulare zu verwenden. Wenn &quot;keine&quot; gew&auml;hlt ist, wird die aktuelle Seite verwendet.';
$lang['info_ccprocessing_module'] = 'Dieses Modul wird f&uuml;r die manuelle Kreditkartenbearbeitung verwendet';
$lang['info_coupon_code'] = 'Bitte geben sie einen Couponschl&uuml;ssel f&uuml;r eine Erm&auml;&szlig;igung ein.';
$lang['info_default_templates'] = 'Dieses Template wird verwendet, wenn Sie auf &quot;Neues Template&quot; im Reiter &quot;Best&auml;tigungs-Formular Template&quot; klicken. Wenn Sie diesen Text &auml;ndern, wird dies keinen Effekt auf die aktuelle Ausgabe der Webseite haben.';
$lang['info_edit_report_template'] = 'Diese Templates legen Stil und Layout eines Reports fest.';
$lang['info_encryption_key'] = 'Dieser Code wurde via Zufalls-Prinzip erzeugt, als dieses Modul installiert wurde. Wenn Sie diesen Wert &auml;ndern und bereits Bestellungen vorliegen, k&ouml;nnen Probleme auftreten.';
$lang['info_forcessl'] = '<strong>Achtung: Empfohlen</strong>. Wenn Sie Kunden erlauben, ihre Kreditkarten-Daten anzugeben, sollten Sie diese Option aktivieren. Damit wird die &Uuml;bertragung via SSL verschl&uuml;sselt, um die Kreditkartendaten sicher zu &uuml;bertragen.';
$lang['info_gateway_description'] = 'Diese Information wird f&uuml;r jede Transaktion zum Payment-Gateway &uuml;bertragen. Sie kann benutzt werden f&uuml;r den Name, der auf der Kreditkartenabrechnung der Kunden stehen soll.';
$lang['info_incomplete_timeout'] = 'Offene Bestellungen die die gesetzte Zeit in Minuten nicht bearbeitet wurden k&ouml;nnen automatisch auf unvollendet gesetzt werden.  Setzen Sie den Wert auf 0 um die Funktion zu deaktivieren.';
$lang['info_invoicepage'] = '<strong>Achtung:</strong> Diese Seite wird auch als Erfolgs- und Fehlerseite f&uuml;r die Payment Gateways verwendet.';
$lang['inform_no_cc_processing'] = 'Sind Sie  sich bewusst, dass Sie  bereits vorhandene Zahlungsinformationen bearbeiten?\nEs wird keine neue Kreditkarten-Transaktion verarbeitet.';
$lang['info_order_notes'] = 'Anmerkungen zu dieser Bestellung.';
$lang['info_require_membergroup'] = 'Diese Einstellung wird nur ber&uuml;cksichtigt, wenn Kunden NICHT anonym bestellen k&ouml;nnen.';
$lang['info_skip_invoice_page'] = 'Wenn die Nutzer Zahlungsdaten angeben sollen, sollen diese dann auf die Rechnungsseite weitergeleitet werden, oder direkt zur Transaktions-Best&auml;tigungs-Seite?';
$lang['info_store_creditcard_data'] = '<strong>Achtung: <span style=&quot;color: red;&quot;>Nicht empfohlen</span></strong> Die Kreditkarten-Daten werden bei Aktivierung dieser Option in der Datenbank gespeichert.<br/>Obwohl die Daten verschl&uuml;sselt gespeichert werden,<br/>wird diese Einstellung nicht empfohlen.<br/>Besser ist es, ein kompatibles Zahlungsmodul zu verwenden.';
$lang['info_useremail_template'] = 'In diesem Template kann das Layout und der Inhalt der EMail festgelegt werden, die bei einer neuen Bestellung an den Kunde gesendet wird.';
$lang['info_validcountries'] = 'Geben Sie eine Liste der L&auml;ndercodes und L&auml;ndernamen ein, die im Adresseingabeformular angezeigt werden sollen (ein Eintrag pro Zeile). Bsp.: US=Vereinigte  Staaten von Amerika. Wenn Sie nichts eingeben, wird die Standard-L&auml;nderliste verwendet.';
$lang['info_validstates'] = 'Geben Sie eine Liste der K&uuml;rzel und Namen f&uuml;r Bundesstaaten oder Provinzen ein, die im Adresseingabeformular angezeigt werden sollen (ein Eintrag pro Zeile). Bsp.: AB=Alberta. Wenn Sie nichts eingeben, wird die Standard-Bundesstaatenliste verwendet.';
$lang['info_use_integer'] = 'Nur ganzzahlige Werte verwenden';
$lang['interval_oneday'] = 'Ein Tag';
$lang['interval_onemonth'] = 'Ein Monat';
$lang['interval_onequarter'] = 'Ein Quartal';
$lang['interval_oneweek'] = 'Eine Woche';
$lang['interval_oneyear'] = 'Ein Jahr';
$lang['interval_twoweeks'] = 'Zwei Wochen';
$lang['invoice'] = 'Rechnung';
$lang['invoiced'] = 'in Rechnung gestellt';
$lang['invoice_settings'] = 'Rechnungseinstellungen';
$lang['invoice_templates'] = 'Rechnungsvorlagen';
$lang['items'] = 'Artikel';
$lang['last_name'] = 'Nachname';
$lang['last_modified'] = 'zuletzt bearbeitet';
$lang['lastpage'] = '>>';
$lang['lbl_back'] = 'zur&uuml;ck';
$lang['lbl_preferences'] = 'Einstellungen';
$lang['lbl_templates'] = 'Vorlagen';
$lang['legend_dates'] = 'Zeitraum w&auml;hlen';
$lang['legend_reports'] = 'Reporte';
$lang['message'] = 'Nachricht';
$lang['message_templates'] = 'Nachrichtenvorlagen';
$lang['method'] = 'Methode';
$lang['moddescription'] = 'Ein einfaches Modul zur Bearbeitung von Bestellungen';
$lang['modified'] = 'ge&auml;ndert';
$lang['msg_async_transaction'] = 'Handled Async Transcation %s for order %s';
$lang['msg_order_cancelled'] = 'Bestellung %s abgebrochen oder abgewiesen';
$lang['msg_order_error'] = 'Bei der Bestellung %s ist ein Fehler aufgetreten';
$lang['msg_order_payment'] = 'Bezahlung f&uuml;r Bestellung %s erhalten.';
$lang['msg_order_pending'] = 'Bestellungsstatus bei %s zu &bdquo;ausstehend&ldquo; ge&auml;ndert.';
$lang['msg_payment_cancelled'] = 'Zahlung %s f&uuml;r Bestellung %s wurde abgebrochen';
$lang['msg_payment_declined'] = 'Zahlung %s f&uuml;r Bestellung %s wurde abgelehnt';
$lang['msg_payment_error'] = 'W&auml;hrend Zahlung %s f&uuml;r Bestellung %s trat ein Fehler auf';
$lang['msg_payment_received'] = 'Zahlung %s (%s) f&uuml;r Bestellung %s erhalten';
$lang['msg_payment_removed'] = 'Bezahlung von der Bestellung entfernt';
$lang['msg_payment_setbackwards'] = 'Es wurde versucht, den Status der Bestellung% s von GEZAHLT auf OFFEN zur&uuml;ckzusetzen';
$lang['name'] = 'Name';
$lang['net'] = 'Netto';
$lang['net_price'] = 'Nettopreis';
$lang['new_order_submitted'] = 'Eine neue Bestellung ist eingegangen';
$lang['next'] = 'weiter';
$lang['nextpage'] = '>';
$lang['no'] = 'nein';
$lang['no_items_in_cart'] = 'Es sind keine Artikel im Warenkorb. Bitte f&uuml;gen sie welche hinzu bevor sie zur Kasse gehen.';
$lang['no_report_data'] = 'Keine passenden Daten gefunden';
$lang['none'] = 'keine Vorgabe';
$lang['notcancelledshipped'] = 'alles au&szlig;er versandt und abgebrochen';
$lang['notes'] = 'Bemerkungen';
$lang['notshipped'] = 'nicht versandt';
$lang['num'] = 'Nr.';
$lang['online'] = 'online';
$lang['order'] = 'Bestellung';
$lang['orders'] = 'Bestellungen';
$lang['order_confirm_form_templates'] = 'Bestellungsbest&auml;tigungsformularvorlagen';
$lang['order_details'] = 'Details der Bestellung';
$lang['order_notes'] = 'Bestellungsnotizen';
$lang['order_number'] = 'Bestellnr.';
$lang['order_processing'] = 'Bestellungsverarbeitung';
$lang['order_statistics'] = 'Bestellungsstatistiken';
$lang['order_summary'] = 'Bestellungszusammenfassung';
$lang['ORDERS_ITEMTYPE_DISCOUNT'] = 'Erm&auml;&szlig;igung';
$lang['paid'] = 'bezahlt';
$lang['payment_amount'] = 'Zahlungsbetrag';
$lang['payment_approved'] = 'genehmigt';
$lang['payment_cancelled'] = 'abgebrochen';
$lang['payment_date'] = 'Zahlungsdatum';
$lang['payment_declined'] = 'abgewiesen';
$lang['payment_error'] = 'Fehler';
$lang['payment_form_templates'] = 'Zahlungsformularvorlagen';
$lang['payment_gateway_settings'] = 'Einstellungen der Zahlungsschnittstelle';
$lang['payment_history'] = 'Bisherige Zahlungen';
$lang['payment_info'] = 'Zahlungsinformationen';
$lang['payment_method'] = 'Zahlungsmethode';
$lang['payment_notprocessed'] = 'nicht bearbeitet';
$lang['payment_options'] = 'Zahlungs-Einstellungen';
$lang['payment_other'] = 'andere';
$lang['payment_pending'] = 'ausstehend';
$lang['payment_status'] = 'Zahlungsstatus';
$lang['pending'] = 'ausstehend';
$lang['phone'] = 'Telefon';
$lang['popup_new_window'] = 'Rechnung in neuem Fenster &ouml;ffnen';
$lang['postinstall'] = 'Das Bestellungsverwaltungsmodul wurde installiert';
$lang['postuninstall'] = 'Das Bestellungsverwaltungsmodul und alle dazugeh&ouml;rigen Daten wurden entfernt';
$lang['post_order_msg'] = 'Nachricht nach der Bestellung';
$lang['postal'] = 'Postleitzahl';
$lang['preferences'] = 'Einstellungen';
$lang['prevpage'] = '<';
$lang['price'] = 'Preis';
$lang['print_invoice'] = 'Rechnung drucken';
$lang['procede_manual_checkout'] = 'manuelle Bestellung';
$lang['process_manual_payment'] = 'Bearbeite Manuelle Zahlung';
$lang['process_new_transaction'] = 'Kreditkartentransaktion &uuml;ber Schnittstelle vollziehen';
$lang['process_order'] = 'Bestellung bearbeiten';
$lang['product_id'] = 'Produkt-ID';
$lang['promotions_module'] = 'Werbemodul';
$lang['promotions_settings'] = 'Werbeeinstellungen';
$lang['prompt_address_property_map'] = 'Eigenschaften aus FrontEndUsers verwenden';
$lang['prompt_address_retrieval'] = 'Art der Adressabfrage';
$lang['prompt_admin_invoice_template'] = 'Vorlage f&uuml;r druckfreundliche Rechnung';
$lang['prompt_allow_anon_checkout'] = 'Erlaube Kunden anonym (ohne FEU Login) zu bestellen.';
$lang['prompt_allow_creditcard_entry'] = 'Kunden die Angabe von Kreditkarteninformationen erlauben';
$lang['prompt_billingpage'] = 'Seite zur Darstellung des Rechnungsformulars &ndash; &uuml;blicherweise ist dies die Seite mit dem <code>{Orders}</code>-Tag.';
$lang['prompt_ccprocessing_module'] = 'Kreditkartenbearbeitungsschnittstelle';
$lang['prompt_confirmpage'] = 'Seite, die f&uuml;r das Best&auml;tigungsformular verwendet werden soll';
$lang['prompt_datastore_timeout'] = 'Verfallszeitraum f&uuml;r tempor&auml;re Transaktionsdaten';
$lang['prompt_date_search_type'] = 'zeige Eintr&auml;ge';
$lang['prompt_dflt_country'] = 'Vorgabe Land';
$lang['prompt_dflt_state'] = 'Vorgabe Bundesstaat';
$lang['prompt_email'] = 'E-Mail-Adresse';
$lang['prompt_encryption_key'] = 'Verschl&uuml;sselungscode';
$lang['prompt_forcessl'] = 'Weiterleiten zu HTTPS f&uuml;r die Eingabe der Zahlungs-Informationen.';
$lang['prompt_gateway_description'] = 'Beschreibung, welche an den Payment Gateway gesendet wird.';
$lang['prompt_incomplete_timeout'] = 'Setze den Bestellstatus automatisch nach N Minuten auf unvollendet <em>(bei offenen Bestellungen)</em>';
$lang['prompt_invoice_message'] = 'Nachricht, die am Anfang aller Rechnungen erscheinen soll';
$lang['prompt_invoicepage'] = 'Seite, die f&uuml;r die Rechnungsansicht verwendet werden soll';
$lang['prompt_of'] = 'Von';
$lang['prompt_ordernum_prefix'] = 'Bestellnummernzusatz';
$lang['prompt_page'] = 'Seite';
$lang['prompt_pagelimit'] = 'Anzahl der Bestellungen pro Seite';
$lang['prompt_paymentpage'] = 'Seite, die f&uuml;r das Zahlungsformular verwendet werden soll';
$lang['prompt_permit_deletion'] = 'erlaube das L&ouml;schen von Bestellungen';
$lang['prompt_requirepostal'] = 'Postleitzahl im Rechnungsformular als Pflichtfeld anzeigen';
$lang['prompt_requirestate'] = 'Bundesstaat/Provinz im Rechnungsformular als Pflichtfeld anzeigen';
$lang['prompt_skip_invoice_page'] = 'Rechnungsseite &uuml;berspringen';
$lang['prompt_store_creditcard_data'] = 'Kreditkarten-Daten dauerhaft speichern';
$lang['prompt_template'] = 'Nachrichtenvorlage';
$lang['prompt_username'] = 'Benutzername';
$lang['prompt_validcountries'] = 'Erlaubte L&auml;nder:';
$lang['prompt_validstates'] = 'Erlaubte Bundesstaaten:';
$lang['proposed'] = 'noch unvollendet';
$lang['quantity'] = 'Menge';
$lang['really_uninstall'] = 'Sind sie sicher, dass sie dies tun wollen? Jegliche Daten, die mit diesem Modul verkn&uuml;pft sind werden verloren gehen, wenn sie fortfahren.';
$lang['records_matching_query'] = 'Anzahl der Ergebnisse, die zu Ihrer Anfrage gefunden wurden';
$lang['regex'] = 'regul&auml;rer Ausdruck';
$lang['remember_last_address_used'] = 'Die Adresse der letzten Bestellung verwenden';
$lang['report'] = 'Report';
$lang['reports'] = 'Reports';
$lang['report_recent_payments'] = 'K&uuml;rzlich erfolgte Zahlungen';
$lang['report_shipping_costs'] = 'Versandkosten';
$lang['report_subscr_picklist'] = 'Subscription Picklist';
$lang['report_templates'] = 'Report Templates';
$lang['return'] = 'zur&uuml;ck';
$lang['require_group_membership'] = 'Um eine Bestellung auszuf&uuml;hren, muss ein Kunde in dieser FrontEndUser-Gruppe angemeldet sein.';
$lang['security_settings'] = 'Sicherheits-Einstellungen';
$lang['select_action'] = 'Aktion w&auml;hlen';
$lang['select_one'] = 'bitte w&auml;hlen';
$lang['select_invoice_template'] = 'Rechnungsvorlage w&auml;hlen';
$lang['send'] = 'Senden';
$lang['send_message'] = 'diesem Kunden eine Nachricht senden';
$lang['sent'] = 'gesendet';
$lang['ship_to'] = 'versenden an';
$lang['shipped'] = 'versandt';
$lang['shipping'] = 'Versandkosten';
$lang['shipping_address'] = 'Versandadresse';
$lang['shipping_costs'] = 'Versandkosten';
$lang['shipping_info'] = 'Versandinformation';
$lang['shipping_info_for'] = 'Lieferadresse f&uuml;r';
$lang['shipping_info_if_different'] = 'Versandinformationen <span>(falls anders als Rechnungsinformationen)</span>';
$lang['shipping_message'] = 'Nachricht f&uuml;r dieses Ziel';
$lang['shipping_module'] = 'Versandmodul';
$lang['shipping_settings'] = 'Versandeinstellungen';
$lang['shipping_total'] = 'Gesamtsumme Versandkosten';
$lang['sku'] = 'Art.-Nr';
$lang['source'] = 'Quelle';
$lang['special_instructions'] = 'spezielle Anweisungen';
$lang['start_date'] = 'Startdatum';
$lang['state/province'] = 'Staat/Provinz <small>(falls aus USA/Kanada)</small>';
$lang['status'] = 'Status';
$lang['subscription'] = 'Vorbestellung';
$lang['subject'] = 'Betreff';
$lang['submit'] = 'Absenden';
$lang['submitted'] = 'Abgesandt';
$lang['submit_payment_info'] = 'Zahlungsinformationen eingeben';
$lang['subscribed'] = 'vorbestellt';
$lang['subtotal'] = 'Zwischensumme';
$lang['tax'] = 'Steuer';
$lang['tax_module'] = 'Steuer-Modul';
$lang['tax_settings'] = 'Steuereinstellungen';
$lang['template'] = 'Vorlage';
$lang['template_name'] = 'Vorlagenname';
$lang['thank_you_for_order'] = 'Vielen Dank f&uuml;r den Einkauf bei {sitename}';
$lang['timeout'] = 'Zeit&uuml;berschreitung';
$lang['title_adminemail_template'] = 'Administrator-E-Mail-Vorlage';
$lang['title_first_page'] = 'Erste Seite anzeigen';
$lang['title_last_page'] = 'Letzte Seite anzeigen';
$lang['title_manage_order'] = 'Bestellungen verwalten';
$lang['title_manual_process'] = 'Manuelle Transaktions-Verarbeitung';
$lang['title_next_page'] = 'N&auml;chste Seite anzeigen';
$lang['title_prev_page'] = 'Vorherige Seite anzeigen';
$lang['title_useremail_template'] = 'Benutzer-E-Mail-Vorlage';
$lang['to'] = 'an';
$lang['total'] = 'Gesamtsumme';
$lang['tracking_num'] = 'Transaktionsnummer';
$lang['transaction_id'] = 'Transaktionsnummer';
$lang['transaction_successful'] = 'Zahlung erfolgreich &uuml;bermittelt';
$lang['type'] = 'Art';
$lang['update_status'] = 'Status aktualisieren';
$lang['unit_price'] = 'St&uuml;ckpreis';
$lang['unit_weight'] = 'Gewicht pro Einheit';
$lang['unknown'] = 'unbekannt';
$lang['unlimited'] = 'Unbeschr&auml;nkt';
$lang['username'] = 'Benutzername';
$lang['user_email_template'] = 'Benutzer-E-Mail-Vorlage';
$lang['view'] = 'ansehen';
$lang['view_message'] = 'Nachricht ansehen';
$lang['view_messages'] = 'Nachrichten f&uuml;r diese Bestellung ansehen';
$lang['warning_https'] = '<strong>Warnung!</strong> Sie benutzen keine verschl&uuml;sselte (https) Verbindung. Es ist nciht empfohlen, ohne eine verschl&uuml;sselte Verbindung fortzufahren.';
$lang['warning_manual_process'] = '<strong>Warnung!</strong> Diese Ansicht erlaubt eine manuelle Verarbeitung von Kreditkarten-Transaktionen &uuml;ber ein Online-Gateway. Seien Sie vorsichtig!';
$lang['warning_orderstatus_paid'] = '<strong>Warnung!</strong> - Diese Bestellung wurde bereits bezahlt. Sie sollten nicht mit einer Zahlung f&uuml;r diese Bestellung fortfahren.';
$lang['warning_orderstatus_cancelled'] = '<strong>Warnung!</strong> - Diese Bestellung wurde abgebrochen. Sie sollten nicht mit einer Zahlung f&uuml;r diese Bestellung fortfahren.';
$lang['warning_no_ccprocessing_gateway'] = '<strong>Warnung!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
$lang['warning_order_paid_in_full'] = '<strong>Warnung!</strong> Diese Bestellung scheint bereits voll bezahlt zu sein.';
$lang['weight'] = 'Gewicht';
$lang['within'] = 'innerhalb';
$lang['yes'] = 'Ja';
$lang['qca'] = 'P0-1362779760-1309265682636';
$lang['utma'] = '156861353.1681295217.1311961821.1312221772.1312224790.5';
$lang['utmz'] = '156861353.1311961821.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
?>